| Title: | Vizualization tools for 'omics' datasets with R |
|---|---|
| Description: | This package contains a collection of functions (written as shiny modules) for the visualisation and the statistical analysis of omics data. These plots can be displayed individually or embedded in a global Shiny module. Additionaly, it is possible to integrate third party modules to the main interface of the package omXplore. |
| Authors: | Samuel Wieczorek [aut, cre] (ORCID: <https://orcid.org/0000-0002-5016-1203>), Thomas Burger [aut], Enora Fremy [ctb], Cyril Ariztegui [ctb], Manon Gaudin [ctb] |
| Maintainer: | Samuel Wieczorek <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.7.0 |
| Built: | 2026-05-30 09:38:20 UTC |
| Source: | https://github.com/bioc/omXplore |
Functions used to access the additional plots in the instances
of the class MultiAssayExperiment.
get_adjacencyMatrix(object, ...) ## S4 method for signature 'SummarizedExperiment' get_adjacencyMatrix(object) get_design(object, ...) ## S4 method for signature 'MultiAssayExperiment' get_design(object) get_group(object, ...) ## S4 method for signature 'MultiAssayExperiment' get_group(object) get_metacell(object, ...) ## S4 method for signature 'SummarizedExperiment' get_metacell(object, slot.name = c("metacell", "qMetacell")) get_cc(object, ...) ## S4 method for signature 'SummarizedExperiment' get_cc(object) get_parentProtId(object, ...) ## S4 method for signature 'SummarizedExperiment' get_parentProtId(object) get_colID(object, ...) ## S4 method for signature 'SummarizedExperiment' get_colID(object) get_type(object, ...) ## S4 method for signature 'SummarizedExperiment' get_type(object) get_pkg_version(object, ...) ## S4 method for signature 'SummarizedExperiment' get_pkg_version(object)get_adjacencyMatrix(object, ...) ## S4 method for signature 'SummarizedExperiment' get_adjacencyMatrix(object) get_design(object, ...) ## S4 method for signature 'MultiAssayExperiment' get_design(object) get_group(object, ...) ## S4 method for signature 'MultiAssayExperiment' get_group(object) get_metacell(object, ...) ## S4 method for signature 'SummarizedExperiment' get_metacell(object, slot.name = c("metacell", "qMetacell")) get_cc(object, ...) ## S4 method for signature 'SummarizedExperiment' get_cc(object) get_parentProtId(object, ...) ## S4 method for signature 'SummarizedExperiment' get_parentProtId(object) get_colID(object, ...) ## S4 method for signature 'SummarizedExperiment' get_colID(object) get_type(object, ...) ## S4 method for signature 'SummarizedExperiment' get_type(object) get_pkg_version(object, ...) ## S4 method for signature 'SummarizedExperiment' get_pkg_version(object)
object |
An instance of class |
... |
Additional parameters |
slot.name |
The name of the slot dedicated to cell metadata to search. Default values are 'metacell' and 'qMetacell' |
See individual method description for the return value.
If exists, the slot value requested.
A DataFrame containing the adjacency matrix of the dataset
A data.frame containing the metadata of the dataset
A data.frame containing the metadata of the dataset
A data.frame containing the metadata of the dataset
A data.frame containing the metadata of the dataset
A data.frame containing the metadata of the dataset
A data.frame containing the metadata of the dataset
A data.frame containing the metadata of the dataset
A data.frame containing the metadata of the dataset
## ----------------------------------- ## Accessing slots from a MSnSet dataset ## ----------------------------------- data(sub_R25) se1 <- sub_R25[[1]] parentProtId <- get_parentProtId(se1) colID <- get_colID(se1) type <- get_type(se1) metacell <- get_metacell(se1) conds <- get_group(sub_R25)## ----------------------------------- ## Accessing slots from a MSnSet dataset ## ----------------------------------- data(sub_R25) se1 <- sub_R25[[1]] parentProtId <- get_parentProtId(se1) colID <- get_colID(se1) type <- get_type(se1) metacell <- get_metacell(se1) conds <- get_group(sub_R25)
If the cell metadata exists in the object of class SummarizedExperiment,
then these information are added to the quantitative data so as to use
styles with the functions of the package DT.
Build_enriched_qdata(obj)Build_enriched_qdata(obj)
obj |
An instance of the class |
A data.frame with new colums corresponding to the cell metadata (if exists)
NULLNULL
This function builds a list which is used for styling DT tables with the
function DT::styleEqual()
BuildColorStyles(type)BuildColorStyles(type)
type |
The type of dataset. Available values are |
A list
NULLNULL
Shows a legend based on the tags in the package 'DaparToolshed'
custom_metacell_colors() colorLegend_ui(id) colorLegend_server( id, presentTags = reactive({ NULL }), hide.white = TRUE ) colorLegend(dataIn = SummarizedExperiment::SummarizedExperiment())custom_metacell_colors() colorLegend_ui(id) colorLegend_server( id, presentTags = reactive({ NULL }), hide.white = TRUE ) colorLegend(dataIn = SummarizedExperiment::SummarizedExperiment())
id |
A |
presentTags |
A vector of |
hide.white |
A |
dataIn |
An instance of the class |
A vector
NA
NA
A shiny app
if (interactive()) { data(vdata) shiny::runApp(colorLegend(vdata[[1]])) }if (interactive()) { data(vdata) shiny::runApp(colorLegend(vdata[[1]])) }
The resulting object is an instance of the MultiAssayExperiment class.
convert_to_mae(obj) MSnSet_to_mae(obj) matrix_to_mae(obj) df_to_mae(obj) Compute_CC(obj) QFeatures_to_mae(obj) SE_to_mae(obj) MAE_to_mae(obj) Check_se_Consistency(obj) list_to_se(ll) Check_List_consistency(ll) listOfLists_to_mae(obj, colData = NULL) listOfSE_to_mae(obj) Check_MSnSet_Consistency(obj) matrix_to_se(obj) df_to_se(obj) MSnSet_to_se(obj) Build_X_CC(se) listOfMSnSet_to_mae(obj) listOfmatrix_to_mae(obj) listOfdf_to_mae(obj)convert_to_mae(obj) MSnSet_to_mae(obj) matrix_to_mae(obj) df_to_mae(obj) Compute_CC(obj) QFeatures_to_mae(obj) SE_to_mae(obj) MAE_to_mae(obj) Check_se_Consistency(obj) list_to_se(ll) Check_List_consistency(ll) listOfLists_to_mae(obj, colData = NULL) listOfSE_to_mae(obj) Check_MSnSet_Consistency(obj) matrix_to_se(obj) df_to_se(obj) MSnSet_to_se(obj) Build_X_CC(se) listOfMSnSet_to_mae(obj) listOfmatrix_to_mae(obj) listOfdf_to_mae(obj)
obj |
An object compliant with the formats accepted by |
ll |
A list |
colData |
A data.frame() |
se |
AN instance of the class |
An enriched instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
An instance of SimpleList
An enriched instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
A boolean(1)
An enriched instance of the class SummarizedExperiment
A boolean(1)
An enriched instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
A boolean(1)
An enriched instance of the class SummarizedExperiment
An enriched instance of the class SummarizedExperiment
An enriched instance of the class SummarizedExperiment
An enriched instance of the class SummarizedExperiment
An enriched instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
#------------------------------------------- # Conversion of a MultiAssayExperiment instance #------------------------------------------- data(miniACC, package = "MultiAssayExperiment") convert_to_mae(miniACC)#------------------------------------------- # Conversion of a MultiAssayExperiment instance #------------------------------------------- data(miniACC, package = "MultiAssayExperiment") convert_to_mae(miniACC)
Displays a correlation matrix of the quantitative data of a numeric matrix.
omXplore_corrmatrix_ui(id) omXplore_corrmatrix_server( id, dataIn = reactive({ NULL }), i = reactive({ 1 }) ) corrMatrix(data, rate = 0.5, showValues = FALSE) omXplore_corrmatrix(dataIn, i)omXplore_corrmatrix_ui(id) omXplore_corrmatrix_server( id, dataIn = reactive({ NULL }), i = reactive({ 1 }) ) corrMatrix(data, rate = 0.5, showValues = FALSE) omXplore_corrmatrix(dataIn, i)
id |
A |
dataIn |
An instance of the class |
i |
An integer which is the index of the assay in the param dataIn |
data |
An object of class 'matrix' |
rate |
The rate parameter to control the exponential law for the gradient of colors |
showValues |
A boolean which indicates whether to show values in the correlation plot. |
NA
NA
A plot
A shiny app
if (interactive()) { data(vdata) omXplore_corrmatrix(vdata, 1) }if (interactive()) { data(vdata) omXplore_corrmatrix(vdata, 1) }
Displays a correlation matrix of the quantitative data of a numeric matrix.
omXplore_density_ui(id) omXplore_density_server( id, dataIn = reactive({ NULL }), i = reactive({ 1 }), pal.name = reactive({ NULL }) ) densityPlot(data, conds = NULL, pal.name = NULL) omXplore_density(dataIn, i)omXplore_density_ui(id) omXplore_density_server( id, dataIn = reactive({ NULL }), i = reactive({ 1 }), pal.name = reactive({ NULL }) ) densityPlot(data, conds = NULL, pal.name = NULL) omXplore_density(dataIn, i)
id |
A |
dataIn |
An instance of the class |
i |
An integer which is the index of the assay in the param obj |
pal.name |
A |
data |
A data.frame() of quantitative data |
conds |
A vector indicating the name of each sample. |
NA
NA
A plot
A shiny app
if (interactive()) { data(vdata) shiny::runApp(omXplore_density(vdata, 1)) } if (interactive()) { data(vdata) qdata <- SummarizedExperiment::assay(vdata[[1]]) conds <- get_group(vdata) densityPlot(qdata, conds) }if (interactive()) { data(vdata) shiny::runApp(omXplore_density(vdata, 1)) } if (interactive()) { data(vdata) qdata <- SummarizedExperiment::assay(vdata[[1]]) conds <- get_group(vdata) densityPlot(qdata, conds) }
Process a PCA, using nipals or FactoMineR, on a quantitative dataset.
This method plots a bar plot which represents the distribution of the number of missing values (NA) per lines (ie proteins).
wrapper_pca()
plotPCA_Eigen_hc(): plots the eigen values of PCA with the plotly
library
plotPCA_Eigen(): plots the eigen values of PCA
plotPCA_Var()
plotPCA_Ind()
my_PCA( X, scale.unit = TRUE, ncp = min(12, nrow(X) - 1, ncol(X)), ind.sup = NULL, quanti.sup = NULL, quali.sup = NULL, row.w = NULL, col.w = NULL, graph = FALSE, axes = c(1, 2), approach = "FM", gramschmidt = TRUE ) omXplore_pca_ui(id) omXplore_pca_server(id, dataIn, i) omXplore_pca(dataIn, i) wrapper_pca( qdata, group, var.scaling = TRUE, ncp = NULL, approach = "FM", gramschmidt = TRUE ) plotPCA_Eigen(res.pca) plotPCA_Var(res.pca, chosen.axes = c(1, 2)) plotPCA_Ind(res.pca, chosen.axes = c(1, 2)) plotPCA_Eigen_hc(res.pca)my_PCA( X, scale.unit = TRUE, ncp = min(12, nrow(X) - 1, ncol(X)), ind.sup = NULL, quanti.sup = NULL, quali.sup = NULL, row.w = NULL, col.w = NULL, graph = FALSE, axes = c(1, 2), approach = "FM", gramschmidt = TRUE ) omXplore_pca_ui(id) omXplore_pca_server(id, dataIn, i) omXplore_pca(dataIn, i) wrapper_pca( qdata, group, var.scaling = TRUE, ncp = NULL, approach = "FM", gramschmidt = TRUE ) plotPCA_Eigen(res.pca) plotPCA_Var(res.pca, chosen.axes = c(1, 2)) plotPCA_Ind(res.pca, chosen.axes = c(1, 2)) plotPCA_Eigen_hc(res.pca)
X |
a data.frame() of quantitative data |
scale.unit |
See |
ncp |
See |
ind.sup |
See |
quanti.sup |
See |
quali.sup |
See |
row.w |
See |
col.w |
See |
graph |
See |
axes |
See |
approach |
a string corresponding to the package to use for PCA (if no |
gramschmidt |
A boolean indicating whether to use Gram-Schmidt orthogonalization or not. |
id |
A |
dataIn |
An instance of the class |
i |
An integer which is the index of the assay in the param obj |
qdata |
A data.frame() of quantitative data |
group |
A vector with the name of samples |
var.scaling |
A boolean indicating whether to scale the data or not |
res.pca |
The result of the function |
chosen.axes |
See the parameter 'axes' of the function
|
res.pca a "PCA" "list" object
NA
NA
A shiny app
The result of the function FactoMineR::PCA()
A plot
A plot
A plot
A plot
Samuel Wieczorek, Enora Fremy
if (interactive()) { data(vdata) obj <- vdata[[1]] res.pca <- my_PCA(SummarizedExperiment::assay(obj), approach = "FM") plotPCA_Eigen(res.pca) plotPCA_Var(res.pca) plotPCA_Eigen_hc(res.pca) plotPCA_Ind(res.pca) } if (interactive()) { data(vdata) library(shiny) library(dplyr) library(plotly) # Replace missing values for the example sel <- is.na(SummarizedExperiment::assay(vdata, 1)) SummarizedExperiment::assay(vdata[[1]])[sel] <- 0 SummarizedExperiment::assay(vdata[[1]])[1, 1] <- NA omXplore_pca(vdata, 1) } if (interactive()) { data(vdata) obj <- vdata[[1]] res.pca <- wrapper_pca(qdata = SummarizedExperiment::assay(obj), group = get_group(obj)) plotPCA_Eigen(res.pca) plotPCA_Var(res.pca) plotPCA_Eigen_hc(res.pca) plotPCA_Ind(res.pca) }if (interactive()) { data(vdata) obj <- vdata[[1]] res.pca <- my_PCA(SummarizedExperiment::assay(obj), approach = "FM") plotPCA_Eigen(res.pca) plotPCA_Var(res.pca) plotPCA_Eigen_hc(res.pca) plotPCA_Ind(res.pca) } if (interactive()) { data(vdata) library(shiny) library(dplyr) library(plotly) # Replace missing values for the example sel <- is.na(SummarizedExperiment::assay(vdata, 1)) SummarizedExperiment::assay(vdata[[1]])[sel] <- 0 SummarizedExperiment::assay(vdata[[1]])[1, 1] <- NA omXplore_pca(vdata, 1) } if (interactive()) { data(vdata) obj <- vdata[[1]] res.pca <- wrapper_pca(qdata = SummarizedExperiment::assay(obj), group = get_group(obj)) plotPCA_Eigen(res.pca) plotPCA_Var(res.pca) plotPCA_Eigen_hc(res.pca) plotPCA_Ind(res.pca) }
plotly.This method plots a bar plot which represents the distribution of the number of missing values (NA) per lines (i.e. proteins).
view_dataset_ui(id) view_dataset_server( id, dataIn = reactive({ NULL }), addons = list(), verbose = FALSE ) view_dataset(dataIn = NULL, addons = NULL)view_dataset_ui(id) view_dataset_server( id, dataIn = reactive({ NULL }), addons = list(), verbose = FALSE ) view_dataset(dataIn = NULL, addons = NULL)
id |
A |
dataIn |
An instance of the class |
addons |
A
|
verbose |
A boolean for verbose mode. Default is FALSE. |
distribution of the missing values per line,
a bar plot which represents the distribution of the number of missing values (NA) per lines (i.e. proteins) and per conditions,
Histogram of missing values.
Variance : Builds a densityplot of the CV of entities in numeric matrix.
The CV is calculated for each condition present in the dataset
(see the slot 'Condition' in the colData() DataFrame)
Heatmap:
The function heatmapD()
The function [] is inspired from the function 'heatmap.2' that displays a numeric matrix. For more information, please refer to the help of the heatmap.2 function.
NA
NA
NA
A shiny application which wraps the functions view_dataset_ui() and the view_dataset_server()
#' - distribution of the missing values per line,
a bar plot which represents the distribution of the number of missing values (NA) per lines (ie proteins) and per conditions,
Histogram of missing values.
Samuel Wieczorek, Enora Fremy
if (interactive()) { library(shiny) library(omXplore) data(vdata) addons <- list(omXplore = c("extFoo1", "extFoo2")) runApp(omXplore::view_dataset(vdata, addons)) omXplore::view_dataset(vdata) } if (interactive()) { data(vdata) view_dataset(vdata) }if (interactive()) { library(shiny) library(omXplore) data(vdata) addons <- list(omXplore = c("extFoo1", "extFoo2")) runApp(omXplore::view_dataset(vdata, addons)) omXplore::view_dataset(vdata) } if (interactive()) { data(vdata) view_dataset(vdata) }
Example for an external shiny module, well structured to be run within a
workflow for MagellanNTK
extFoo1_ui(id) extFoo1_server( id, dataIn = reactive({ NULL }), i = reactive({ NULL }) ) extFoo1(dataIn, i) extFoo2_ui(id) extFoo2_server( id, dataIn = reactive({ NULL }), i = reactive({ NULL }) ) extFoo2(dataIn, i)extFoo1_ui(id) extFoo1_server( id, dataIn = reactive({ NULL }), i = reactive({ NULL }) ) extFoo1(dataIn, i) extFoo2_ui(id) extFoo2_server( id, dataIn = reactive({ NULL }), i = reactive({ NULL }) ) extFoo2(dataIn, i)
id |
A |
dataIn |
An object of instance |
i |
An integer which is the index of the assay in the param obj |
NA
NA
NA
A shiny app
NA
NA
A shiny app
if (interactive()) { data(vdata) app1 <- extFoo1(vdata, 1) app2 <- extFoo2(vdata, 1) shiny::runApp(app1) shiny::runApp(app2) }if (interactive()) { data(vdata) app1 <- extFoo1(vdata, 1) app2 <- extFoo2(vdata, 1) shiny::runApp(app1) shiny::runApp(app2) }
A shiny Module.
See DT package homepage for more details about styling tables.
If no style is precised, this module show the raw data.
If any style is given, then the dataset must be well configured (I.e. it
must contain the correct columns )
formatDT_ui(id) formatDT_server( id, data = reactive({ NULL }), data_nostyle = reactive({ NULL }), withDLBtns = FALSE, showRownames = FALSE, dt_style = reactive({ NULL }), filename = "Prostar_export", selection = "single" ) formatDT(data)formatDT_ui(id) formatDT_server( id, data = reactive({ NULL }), data_nostyle = reactive({ NULL }), withDLBtns = FALSE, showRownames = FALSE, dt_style = reactive({ NULL }), filename = "Prostar_export", selection = "single" ) formatDT(data)
id |
shiny id |
data |
A |
data_nostyle |
A data.frame() to be bind to the main data with no custom style |
withDLBtns |
A boolean to indicate whether to display download buttons or not. |
showRownames |
A boolean to indicate whether to show rownames. |
dt_style |
A
|
filename |
A |
selection |
A |
NA
NA
NA
NA
if (interactive()) { data(vdata) formatDT(vdata) }if (interactive()) { data(vdata) formatDT(vdata) }
This function builds the skeleton of a dataset which can be used by the module formatDT. It creates additional columns to be used to style the table. to colors cells.
FormatDataForDT(se, digits = 2)FormatDataForDT(se, digits = 2)
se |
An instance of the class |
digits |
An 'integer(1)' to specify the number of digits to display in the tables for numerical values. Default is 2. |
A data.frame
NULLNULL
Gets the version number of a package
GetPkgVersion(pkg)GetPkgVersion(pkg)
pkg |
The name of the package |
A character(1) with the name of the package and
its version number.
GetPkgVersion("omXplore")GetPkgVersion("omXplore")
Defines the global variables for the package omXplore
globals()globals()
A list
globals()globals()
Displays different intensity plots.
omXplore_intensity_ui(id) omXplore_intensity_server( id, dataIn = reactive({ NULL }), i = reactive({ 1 }), track.indices = reactive({ NULL }), remoteReset = reactive({ NULL }), is.enabled = reactive({ TRUE }) ) omXplore_intensity(dataIn, i = NULL, withTracking = FALSE) boxPlot(dataIn, conds, legend = NULL, pal = NULL, subset = NULL) violinPlot(data, conds, subset = NULL, pal.name = "Set1")omXplore_intensity_ui(id) omXplore_intensity_server( id, dataIn = reactive({ NULL }), i = reactive({ 1 }), track.indices = reactive({ NULL }), remoteReset = reactive({ NULL }), is.enabled = reactive({ TRUE }) ) omXplore_intensity(dataIn, i = NULL, withTracking = FALSE) boxPlot(dataIn, conds, legend = NULL, pal = NULL, subset = NULL) violinPlot(data, conds, subset = NULL, pal.name = "Set1")
id |
A |
dataIn |
xxxx |
i |
An integer which is the index of the assay in the param obj |
track.indices |
A vector of integers which are the indices of lines to track. |
remoteReset |
An integer to activate the reset functions |
is.enabled |
A boolean that indicates whether the widgets should be enabled or disabled. Default is TRUE |
withTracking |
A |
conds |
A vector indicating the name of each sample. |
legend |
A vector of the conditions (one condition per sample). |
pal |
A basis palette for the boxes which length must be equal to the number of unique conditions in the dataset. |
subset |
A |
data |
xxxx |
pal.name |
A |
NA
NA
A shiny app
A boxplot
A violin plot
Samuel Wieczorek, Anais Courtier, Enora Fremy
if (interactive()) { data(vdata) shiny::runApp(omXplore_intensity(vdata, 1)) data(sub_R25) conds <- legend <- SummarizedExperiment::colData(sub_R25)$group pal <- ExtendPalette(length(unique(conds))) boxPlot(sub_R25[[1]], conds, legend, pal, seq_len(10)) shiny::runApp(omXplore_intensity(sub_R25, 1, withTracking = TRUE)) }if (interactive()) { data(vdata) shiny::runApp(omXplore_intensity(vdata, 1)) data(sub_R25) conds <- legend <- SummarizedExperiment::colData(sub_R25)$group pal <- ExtendPalette(length(unique(conds))) boxPlot(sub_R25[[1]], conds, legend, pal, seq_len(10)) shiny::runApp(omXplore_intensity(sub_R25, 1, withTracking = TRUE)) }
Checks if all slots of the given list are of the same class.
is.listOf(object, obj.class = NULL)is.listOf(object, obj.class = NULL)
object |
A |
obj.class |
The name of the class to search in items of the list. |
A character(1) with the name of the package or NULL
ll <- as.list(LETTERS[1:3]) is.listOf(ll, "data.frame") is.listOf(ll, "character")ll <- as.list(LETTERS[1:3]) is.listOf(ll, "data.frame") is.listOf(ll, "character")
This function is a wrapper to heatmap.2() that displays
assay data in an instance of SummarizedExperiment. For
more details, see heatmap.2().
omXplore_heatmap_ui(id) omXplore_heatmap_server( id, dataIn = reactive({ NULL }), i = reactive({ NULL }) ) omXplore_heatmap(dataIn, i) heatmapD( qdata, conds, distance = "euclidean", cluster = "complete", dendro = FALSE ) mv.heatmap( x, col = grDevices::heat.colors(100), srtCol = NULL, labCol = NULL, labRow = NULL, key = TRUE, key.title = NULL, main = NULL, ylab = NULL ) heatmapForMissingValues( x, col = NULL, srtCol = NULL, labCol = NULL, labRow = NULL, key = TRUE, key.title = NULL, main = NULL, ylab = NULL )omXplore_heatmap_ui(id) omXplore_heatmap_server( id, dataIn = reactive({ NULL }), i = reactive({ NULL }) ) omXplore_heatmap(dataIn, i) heatmapD( qdata, conds, distance = "euclidean", cluster = "complete", dendro = FALSE ) mv.heatmap( x, col = grDevices::heat.colors(100), srtCol = NULL, labCol = NULL, labRow = NULL, key = TRUE, key.title = NULL, main = NULL, ylab = NULL ) heatmapForMissingValues( x, col = NULL, srtCol = NULL, labCol = NULL, labRow = NULL, key = TRUE, key.title = NULL, main = NULL, ylab = NULL )
id |
A |
dataIn |
An instance of a class |
i |
An integer which is the index of the assay in the param obj |
qdata |
A data.frame() of quantitative data. |
conds |
A vector indicating the name of each sample. |
distance |
The distance used by the clustering algorithm to compute the dendrogram. |
cluster |
the clustering algorithm used to build the dendrogram. |
dendro |
A boolean to indicate fi the dendrogram has to be displayed |
x |
A |
col |
Colors used for the image. Defaults to heat colors (heat.colors). |
srtCol |
Angle of column conds, in degrees from horizontal |
labCol |
Character vectors with column conds to use. |
labRow |
Character vectors with row conds to use. |
key |
Logical indicating whether a color-key should be shown. |
key.title |
Main title of the color key. If set to NA no title will be plotted. |
main |
Main title; default to none. |
ylab |
y-axis title; default to none. |
NA
NA
A shiny app
A heatmap
A heatmap
A heatmap
Florence Combes, Samuel Wieczorek, Enora Fremy
if (interactive()) { data(vdata) omXplore_heatmap(vdata, 1) }if (interactive()) { data(vdata) omXplore_heatmap(vdata, 1) }
MultiAssayExperiment objects.Explore MultiAssayExperiment objects.
omXplore_tabExplorer_ui(id) omXplore_tabExplorer_server( id, dataIn = reactive({ NULL }), i = reactive({ NULL }), digits = reactive({ 3 }) ) omXplore_tabExplorer(dataIn, i)omXplore_tabExplorer_ui(id) omXplore_tabExplorer_server( id, dataIn = reactive({ NULL }), i = reactive({ NULL }), digits = reactive({ 3 }) ) omXplore_tabExplorer(dataIn, i)
id |
A |
dataIn |
An instance of the class |
i |
An integer which is the index of the assay in the param obj |
digits |
An integer for the number of digits shown in the table |
NA
NA
NA
A shiny app
if (interactive()) { data(vdata) shiny::runApp(omXplore_tabExplorer(vdata, 1)) } NULLif (interactive()) { data(vdata) shiny::runApp(omXplore_tabExplorer(vdata, 1)) } NULL
omXplore
These functions are relative to external modules that can be added into
omXplore UI:
listShinyApps(): Show the shiny modules recognized by omXplore and
ready to bu integrated in the UI of the function view_dataset()
listPlotModules(): Show the shiny modules function names (only prefixes)
recognized by omXplore and ready to use in the UI.
addModules(): Add external shiny module(s) to the R global environment in
such a way (specific prefix renaming of the functions) that it can be
discovered by the function view_dataset() of the package omXplore during
its launch.
addModules(addons = list()) listShinyApps(location = "both") listPlotModules(location = "both")addModules(addons = list()) listShinyApps(location = "both") listPlotModules(location = "both")
addons |
A
|
location |
A |
NA
A vector
A vector
listShinyApps() listPlotModules() ##################################################### # Integration of a module in the package 'mypackage' ##################################################### addons <- list(omXplore = c("extFoo1", "extFoo2")) addModules(addons)listShinyApps() listPlotModules() ##################################################### # Integration of a module in the package 'mypackage' ##################################################### addons <- list(omXplore = c("extFoo1", "extFoo2")) addModules(addons)
Builds a vector of #conditions colors for a set of samples. One color is
given for a given condition. This function extends a base palette from the
package RColorBrewer::RColorBrewer to 'n' colors.
The colors in the returned palette are always in the same order
SampleColors(conds, pal.name = "Set1") ExtendPalette(n, pal.name = "Set1") GetColorsForConditions(conds, pal = NULL)SampleColors(conds, pal.name = "Set1") ExtendPalette(n, pal.name = "Set1") GetColorsForConditions(conds, pal = NULL)
conds |
A |
pal.name |
A |
n |
The number of desired colors in the palette |
pal |
A vector of HEX color code that form the basis palette from which to build the complete color vector for the conditions. |
A vector
A vector
A vector
if (interactive()) { #----------------------------------------------- # Builds a palette for a dataset with 3 conditions # of 3 samples each. #------------------------------------------------ conds <- c(rep("A", 3), rep("B", 3), rep("C", 3)) SampleColors(conds) SampleColors(conds, "Dark2") #----------------------------------------------- # Extend the default palette to 12 colors #----------------------------------------------- ExtendPalette(12) data(vdata) conds <- get_group(vdata) GetColorsForConditions(conds, ExtendPalette(2)) }if (interactive()) { #----------------------------------------------- # Builds a palette for a dataset with 3 conditions # of 3 samples each. #------------------------------------------------ conds <- c(rep("A", 3), rep("B", 3), rep("C", 3)) SampleColors(conds) SampleColors(conds, "Dark2") #----------------------------------------------- # Extend the default palette to 12 colors #----------------------------------------------- ExtendPalette(12) data(vdata) conds <- get_group(vdata) GetColorsForConditions(conds, ExtendPalette(2)) }
Display a CC
Connected Components infos
buildGraph(cc = NULL, meta = NULL) display.CC.visNet(g = NULL, layout = "layout_with_fr") plotCCJitter(df) GetCCInfos(cc)buildGraph(cc = NULL, meta = NULL) display.CC.visNet(g = NULL, layout = "layout_with_fr") plotCCJitter(df) GetCCInfos(cc)
cc |
A list of connected component |
meta |
A data.frame() |
g |
An instance of a graph |
layout |
A |
df |
A data.frame() |
A list
A plot
A plot
A list of three items:
One_One: the number of cc composed of one protein and one peptide
One_Multi: the number of cc composed of one protein and several peptides
Multi_Multi: the number of cc composed of several proteins and
several (shared) peptides.
Thomas Burger, Samuel Wieczorek
if (interactive()) { data(sub_R25) se <- sub_R25[[1]] g <- buildGraph(get_cc(se)[[1]]) display.CC.visNet(g) } if (interactive()) { data(sub_R25) GetCCInfos(get_cc(sub_R25[[1]])) }if (interactive()) { data(sub_R25) se <- sub_R25[[1]] g <- buildGraph(get_cc(se)[[1]]) display.CC.visNet(g) } if (interactive()) { data(sub_R25) GetCCInfos(get_cc(sub_R25[[1]])) }
Checks if a package is available to load it
pkgs.require2(ll.deps)pkgs.require2(ll.deps)
ll.deps |
A |
NA
Samuel Wieczorek
pkgs.require2("omXplore")pkgs.require2("omXplore")
A shiny module which plots the variance of samples
omXplore_variance_ui(id) omXplore_variance_server(id, dataIn, i, pal.name = NULL) CVDist(dataIn, conds, pal.name = NULL) omXplore_variance(dataIn, i)omXplore_variance_ui(id) omXplore_variance_server(id, dataIn, i, pal.name = NULL) CVDist(dataIn, conds, pal.name = NULL) omXplore_variance(dataIn, i)
id |
A |
dataIn |
An matrix |
i |
An integer which is the index of the assay in the param obj |
pal.name |
A |
conds |
A vector indicating the name of each sample. |
NA
NA
A plot
A shiny app
if (interactive()) { data(vdata) shiny::runApp(omXplore_variance(vdata, 1)) }if (interactive()) { data(vdata) shiny::runApp(omXplore_variance(vdata, 1)) }
Prostar
Convert datasets exported by the package Prostar
SE_Compatibility_with_Prostar_1.x(obj, se) MAE_Compatibility_with_Prostar_1x(obj, mae)SE_Compatibility_with_Prostar_1.x(obj, se) MAE_Compatibility_with_Prostar_1x(obj, mae)
obj |
An instance of the class |
se |
An instance of the class |
mae |
An instance of the class |
An enriched instance of the class SummarizedExperiment
An enriched instance of the class MultiAssayExperiment
data(sub_R25)data(sub_R25)
This function gives the vocabulary used for the quantitative metadata of each entity in each condition.
metacell.def(level) Parent(level, node = NULL) Children(level, parent = NULL) GetMetacellTags(metacells = NULL, level = NULL, onlyPresent = FALSE)metacell.def(level) Parent(level, node = NULL) Children(level, parent = NULL) GetMetacellTags(metacells = NULL, level = NULL, onlyPresent = FALSE)
level |
A string corresponding to the type of object |
node |
The name of the node for which one wants its parent |
parent |
The name og the parent node |
metacells |
A data.frame() representing the cell metadata |
onlyPresent |
A |
A data.frame containing the different tags and corresponding colors for the level given in parameter
A list
A vector
A vector
A vector
Peptide-level vocabulary
|– 'Any' | | | |– 1.0 'Quantified' | | | | | |– 1.1 "Quant. by direct id" (color 4, white) | | | | | |– 1.2 "Quant. by recovery" (color 3, lightgrey) | | | |– 2.0 "Missing" (no color) | | | | | |– 2.1 "Missing POV" (color 1) | | | | | |– 2.2 'Missing MEC' (color 2) | | | |– 3.0 'Imputed' | | | | | |– 3.1 'Imputed POV' (color 1) | | | | | |– 3.2 'Imputed MEC' (color 2)
Protein-level vocabulary: |– 'Any' | | | |– 1.0 'Quantified' | | | | | |– 1.1 "Quant. by direct id" (color 4, white) | | | | | |– 1.2 "Quant. by recovery" (color 3, lightgrey) | | | |– 2.0 "Missing" | | | | | |– 2.1 "Missing POV" (color 1) | | | | | |– 2.2 'Missing MEC' (color 2) | | | |– 3.0 'Imputed' | | | | | |– 3.1 'Imputed POV' (color 1) | | | | | |– 3.2 'Imputed MEC' (color 2) | | | |– 4.0 'Combined tags' (color 3bis, lightgrey)
A generic conversion
Conversion for Proline datasets
Conversion from Maxquant datasets
Thomas Burger, Samuel Wieczorek
Samuel Wieczorek
if (interactive()) { metacell.def("protein") metacell.def("peptide") } Parent("protein", "Missing") Parent("protein", "Missing POV") Parent("protein", c("Missing POV", "Missing MEC")) Parent("protein", c("Missing", "Missing POV", "Missing MEC")) Children("protein", "Missing") Children("protein", "Missing POV") Children("protein", c("Missing POV", "Missing MEC")) Children("protein", c("Missing", "Missing POV", "Missing MEC")) data(vdata) metacells <- get_metacell(vdata[[1]]) level <- get_type(vdata[[1]]) GetMetacellTags(metacells, level)if (interactive()) { metacell.def("protein") metacell.def("peptide") } Parent("protein", "Missing") Parent("protein", "Missing POV") Parent("protein", c("Missing POV", "Missing MEC")) Parent("protein", c("Missing", "Missing POV", "Missing MEC")) Children("protein", "Missing") Children("protein", "Missing POV") Children("protein", c("Missing POV", "Missing MEC")) Children("protein", c("Missing", "Missing POV", "Missing MEC")) data(vdata) metacells <- get_metacell(vdata[[1]]) level <- get_type(vdata[[1]]) GetMetacellTags(metacells, level)
sub_R25 is a protein subset of the dataset 'Exp1_R25_pept' in the
package DAPARdata.
An instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
sub_R25 was built from the source code available in
inst/scripts/build_datasets.R
The DAPARdata package: https://github.com/edyp-lab/DAPARdata
vdata is a small object for testing and
demonstration.
An instance of the class MultiAssayExperiment
An enriched instance of the class MultiAssayExperiment
vdata was built from the source code available in
inst/scripts/build_datasets.R